@@ -19,6 +19,6 @@
 
 LIBDIR = r'/usr/local/lib'
 DATADIR = r'/usr/local/share'
-BUILDDIR = r'/usr/obj/ports/gst-devtools-1.26.10/build-powerpc'
-SRCDIR = r'/usr/obj/ports/gst-devtools-1.26.10/gst-devtools-1.26.10'
-GST_VALIDATE_TESTSUITE_VERSION = '1.26'
+BUILDDIR = r'/usr/obj/ports/gst-devtools-1.28.0/build-amd64'
+SRCDIR = r'/usr/obj/ports/gst-devtools-1.28.0/gst-devtools-1.28.0'
+GST_VALIDATE_TESTSUITE_VERSION = '1.28'
